;; Generated package description from realgud-node-inspect.el  -*- no-byte-compile: t -*-
(define-package "realgud-node-inspect" "1.0.0.0.20190526.154549" "Realgud front-end to newer \"node inspect\"" '((realgud "1.4.5") (load-relative "1.2") (cl-lib "0.5") (emacs "24")) :commit "c3ed48cf3bc2b28f9fd23bcf60ea13a3cf019fc8" :authors '(("Rocky Bernstein" . "rocky@gnu.org")) :maintainer '("Rocky Bernstein" . "rocky@gnu.org") :url "http://github.com/realgud/realgud-node-inspect")
